from enum import Enum
from typing import Annotated
import typer

from knoc.workflows import all_wfs

app = typer.Typer(no_args_is_help=True)

workflows = Enum("workflows", {k: k for k in all_wfs})


@app.command()
def list():
    """List all workflows"""

    typer.echo("\n".join([name for name in all_wfs]))


@app.command()
def run(workflow: workflows):  # type: ignore
    """Run a workflow"""
    if workflow.name not in all_wfs:
        typer.echo(
            f"Unknown workflow {workflow.name}. Use 'list' to view all workflows"
        )
        raise typer.Exit(1)
    wf = all_wfs[workflow.name]
    result = wf.run()  # type: ignore
    typer.echo(result)
